@@ -134,13 +134,15 @@ class TestFileGif(PillowTestCase):
         # Multiframe image
         im = Image.open("Tests/images/dispose_bgnd.gif")
 
+        info = im.info.copy()
+
         out = self.tempfile('temp.gif')
         im.save(out, save_all=True)
         reread = Image.open(out)
 
         for header in important_headers:
             self.assertEqual(
-                im.info[header],
+                info[header],
                 reread.info[header]
             )
 
@@ -207,6 +209,15 @@ class TestFileGif(PillowTestCase):
         except EOFError:
             self.assertEqual(framecount, 5)
 
+    def test_seek_info(self):
+        im = Image.open("Tests/images/iss634.gif")
+        info = im.info.copy()
+
+        im.seek(1)
+        im.seek(0)
+
+        self.assertEqual(im.info, info)
+
     def test_n_frames(self):
         for path, n_frames in [
             [TEST_GIF, 1],
@@ -259,6 +270,39 @@ class TestFileGif(PillowTestCase):
         except EOFError:
             pass
 
+    def test_save_dispose(self):
+        out = self.tempfile('temp.gif')
+        im_list = [
+            Image.new('L', (100, 100), '#000'),
+            Image.new('L', (100, 100), '#111'),
+            Image.new('L', (100, 100), '#222'),
+        ]
+        for method in range(0, 4):
+            im_list[0].save(
+                out,
+                save_all=True,
+                append_images=im_list[1:],
+                disposal=method
+            )
+            img = Image.open(out)
+            for _ in range(2):
+                img.seek(img.tell() + 1)
+                self.assertEqual(img.disposal_method, method)
+
+        # check per frame disposal
+        im_list[0].save(
+            out,
+            save_all=True,
+            append_images=im_list[1:],
+            disposal=tuple(range(len(im_list)))
+            )
+
+        img = Image.open(out)
+
+        for i in range(2):
+            img.seek(img.tell() + 1)
+            self.assertEqual(img.disposal_method, i+1)
+
     def test_iss634(self):
         img = Image.open("Tests/images/iss634.gif")
         # seek to the second frame
@@ -272,9 +316,12 @@ class TestFileGif(PillowTestCase):
 
         out = self.tempfile('temp.gif')
         im = Image.new('L', (100, 100), '#000')
-        im.save(out, duration=duration)
-        reread = Image.open(out)
 
+        # Check that the argument has priority over the info settings
+        im.info['duration'] = 100
+        im.save(out, duration=duration)
+
+        reread = Image.open(out)
         self.assertEqual(reread.info['duration'], duration)
 
     def test_multiple_duration(self):
@@ -366,7 +413,8 @@ class TestFileGif(PillowTestCase):
 
     def test_comment(self):
         im = Image.open(TEST_GIF)
-        self.assertEqual(im.info['comment'], b"File written by Adobe Photoshop\xa8 4.0")
+        self.assertEqual(im.info['comment'],
+                         b"File written by Adobe Photoshop\xa8 4.0")
 
         out = self.tempfile('temp.gif')
         im = Image.new('L', (100, 100), '#000')
@@ -410,8 +458,18 @@ class TestFileGif(PillowTestCase):
 
         # Test appending single frame images
         im = Image.new('RGB', (100, 100), '#f00')
-        ims = [Image.new('RGB', (100, 100), color) for color in ['#0f0', '#00f']]
-        im.save(out, save_all=True, append_images=ims)
+        ims = [Image.new('RGB', (100, 100), color) for color
+               in ['#0f0', '#00f']]
+        im.copy().save(out, save_all=True, append_images=ims)
+
+        reread = Image.open(out)
+        self.assertEqual(reread.n_frames, 3)
+
+        # Tests appending using a generator
+        def imGenerator(ims):
+            for im in ims:
+                yield im
+        im.save(out, save_all=True, append_images=imGenerator(ims))
 
         reread = Image.open(out)
         self.assertEqual(reread.n_frames, 3)
@@ -431,8 +489,6 @@ class TestFileGif(PillowTestCase):
         # that's > 128 items where the transparent color is actually
         # the top palette entry to trigger the bug.
 
-        from PIL import ImagePalette
-
         data = bytes(bytearray(range(1, 254)))
         palette = ImagePalette.ImagePalette("RGB", list(range(256))*3)
 
@@ -536,6 +592,14 @@ class TestFileGif(PillowTestCase):
         finally:
             GifImagePlugin._FORCE_OPTIMIZE = False
 
+    def test_lzw_bits(self):
+        # see https://github.com/python-pillow/Pillow/issues/2811
+        im = Image.open('Tests/images/issue_2811.gif')
+
+        self.assertEqual(im.tile[0][3][0], 11)  # LZW bits
+        # codec error prepatch
+        im.load()
+
 
 if __name__ == '__main__':
     unittest.main()
